@@ -43,6 +43,7 @@ class Api(xuexitong.Xuexitong):
         res = self.requests.get(url)
         self.reserveList = res.json().get("data",{}).get("reserveList",[])
         result = self.reserveList
+
         msg = []
 
         for result in self.reserveList:
@@ -62,16 +63,22 @@ class Api(xuexitong.Xuexitong):
 
         if "msg" in res.json(): return  res.json().get("msg"),{}
 
-        print(res.json(),res.request.url,"\n")
+        # print(res.json(),res.request.url,"\n")
 
         result = res.json().get("data",{}).get("seatReserve",{})
         resmsg = "%s-%s 座位号: %s 时长: %s小时"%( result.get("firstLevelName") ,result.get("secondLevelName") ,result.get("seatNum"),result.get("duration"))
         params = { "itemId":result.get("id",""), "roomId":result.get("roomId"), "seatNum":result.get("seatNum") , "startTime":result.get("startTime"), "endTime":result.get("endTime"),"signDuration":result.get("signDuration") }
         reserveInfo = {"key":resmsg,"params":json.dumps(params,ensure_ascii=False),"status":True ,"create_time":Now() }
 
-        print(reserveInfo)
+        # print(reserveInfo)
         print("正在预约中。。。。。",resmsg)
 
+        # data = self.local.read().get(self.phone+"_msg")
+        # if not data.get("msg"): data["msg"] = [resmsg]
+        # else: data["msg"].append(resmsg)
+
+        # self.local.add(data)
+
         return resmsg,reserveInfo
 
     def leave(self,itemId):
@@ -101,6 +108,19 @@ class Api(xuexitong.Xuexitong):
         print("正在退座中。。。。。")
         print(result)
 
+    def sign(self,itemId):
+        # 签到
+
+        url = self.baseurl+'/data/apps/seat/sign'
+        data = {
+            "id":itemId
+        }
+        res = self.requests.get(url,params=data)
+
+        result = res.json()
+        print("正在签到中。。。。。")
+        print(result)
+
 
     def cancel(self,itemId):
         # 取消预约
@@ -166,6 +186,7 @@ class Api(xuexitong.Xuexitong):
     def login(self,phone="18159086771",password="liuyu000*",**a):
 
         self.requests.cookies.clear()
+        self.phone = phone
         cookies = self.local.read().get(phone,{})
         for cookie in cookies:
             self.requests.cookies.set(cookie,cookies[cookie][0],domain=cookies[cookie][1])
